/* Copyright (C) 2024 GSI Helmholtzzentrum fuer Schwerionenforschung, Darmstadt
   SPDX-License-Identifier: GPL-3.0-only
   Authors: Sergei Zharko [committer] */

/// \file   CbmQaReportFigure.h
/// \brief  Base class for the report figure (header)
/// \author S. Zharko <s.zharko@gsi.de>
/// \since  21.02.2024

#pragma once

#include "CbmQaReportElement.h"
#include "CbmQaReportEngine.h"

namespace cbm::qa::report
{
  /// \class Figure
  /// \brief Figure in the report
  class Figure : public Element {
   public:
    /// \brief Constructor
    /// \param label  Label of the element
    Figure(std::string_view label) : Element(std::string("fig:") + std::string(label)) {}

    /// \brief Destructor
    virtual ~Figure() = default;

    /// \brief Gets body of the element
    /// \param engine  A concrete implementation of the Engine to get the element body
    std::string GetBody(const Engine& engine) const override { return engine.FigureBody(*this); }

    /// \brief Gets caption
    const std::string& GetCaption() const { return fsCaption; }

    /// \brief Gets path suffix to the figure
    const std::string& GetPath() const { return fsPath; }

    /// \brief Sets path to the figure
    /// \param path to the figure, which will be represented in
    void SetPath(std::string_view path) { fsPath = path; }

    /// \brief Sets caption
    void SetCaption(std::string_view caption) { fsCaption = caption; }

   private:
    std::string fsPath    = "";  ///< Relative path
    std::string fsCaption = "";  ///< Figure caption
  };
}  // namespace cbm::qa::report
